######################################################################################################
#                                 Auto-generated Metaflow stub file                                  #
# MF version: 2.17.3                                                                                 #
# Generated on 2025-08-21T22:44:50.324677                                                            #
######################################################################################################

from __future__ import annotations


from .exception import MetaflowException as MetaflowException

DATASTORE_LOCAL_DIR: str

LOCAL_CONFIG_FILE: str

DEFAULT_DATASTORE: str

DEFAULT_ENVIRONMENT: str

DEFAULT_EVENT_LOGGER: str

DEFAULT_METADATA: str

DEFAULT_MONITOR: str

DEFAULT_PACKAGE_SUFFIXES: str

DEFAULT_AWS_CLIENT_PROVIDER: str

DEFAULT_AZURE_CLIENT_PROVIDER: str

DEFAULT_GCP_CLIENT_PROVIDER: str

DEFAULT_SECRETS_BACKEND_TYPE: None

DEFAULT_SECRETS_ROLE: None

DEFAULT_FROM_DEPLOYMENT_IMPL: str

USER: None

DATASTORE_SYSROOT_LOCAL: None

DATASTORE_SYSROOT_S3: None

DATASTORE_SYSROOT_AZURE: None

DATASTORE_SYSROOT_GS: None

CLIENT_CACHE_PATH: str

CLIENT_CACHE_MAX_SIZE: int

CLIENT_CACHE_MAX_FLOWDATASTORE_COUNT: int

CLIENT_CACHE_MAX_TASKDATASTORE_COUNT: int

S3_ENDPOINT_URL: None

S3_VERIFY_CERTIFICATE: None

S3_SERVER_SIDE_ENCRYPTION: None

S3_RETRY_COUNT: int

S3_WORKER_COUNT: int

S3_TRANSIENT_RETRY_COUNT: int

S3_CLIENT_RETRY_CONFIG: dict

RETRY_WARNING_THRESHOLD: int

DATATOOLS_SUFFIX: str

DATATOOLS_S3ROOT: None

TEMPDIR: str

DATATOOLS_CLIENT_PARAMS: dict

DATATOOLS_SESSION_VARS: dict

DATATOOLS_AZUREROOT: None

DATATOOLS_GSROOT: None

DATATOOLS_LOCALROOT: None

AWS_SECRETS_MANAGER_DEFAULT_REGION: None

GCP_SECRET_MANAGER_PREFIX: None

AZURE_KEY_VAULT_PREFIX: None

ARTIFACT_LOCALROOT: str

CARD_SUFFIX: str

CARD_LOCALROOT: None

CARD_S3ROOT: None

CARD_AZUREROOT: None

CARD_GSROOT: None

CARD_NO_WARNING: bool

RUNTIME_CARD_RENDER_INTERVAL: int

AZURE_STORAGE_BLOB_SERVICE_ENDPOINT: None

AZURE_STORAGE_WORKLOAD_TYPE: str

GS_STORAGE_WORKLOAD_TYPE: str

SERVICE_URL: None

SERVICE_RETRY_COUNT: int

SERVICE_AUTH_KEY: None

SERVICE_HEADERS: dict

SERVICE_VERSION_CHECK: bool

DEFAULT_CONTAINER_IMAGE: None

DEFAULT_CONTAINER_REGISTRY: None

INCLUDE_FOREACH_STACK: bool

MAXIMUM_FOREACH_VALUE_CHARS: int

DEFAULT_RUNTIME_LIMIT: int

UI_URL: None

ARGO_WORKFLOWS_CAPTURE_ERROR_SCRIPT: None

CONTACT_INFO: dict

DEFAULT_DECOSPECS: str

ECS_S3_ACCESS_IAM_ROLE: None

ECS_FARGATE_EXECUTION_ROLE: None

BATCH_JOB_QUEUE: None

BATCH_CONTAINER_IMAGE: None

BATCH_CONTAINER_REGISTRY: None

SERVICE_INTERNAL_URL: None

BATCH_EMIT_TAGS: bool

SFN_IAM_ROLE: None

SFN_DYNAMO_DB_TABLE: None

EVENTS_SFN_ACCESS_IAM_ROLE: None

SFN_STATE_MACHINE_PREFIX: None

SFN_EXECUTION_LOG_GROUP_ARN: None

SFN_S3_DISTRIBUTED_MAP_OUTPUT_PATH: None

KUBERNETES_NAMESPACE: str

KUBERNETES_SERVICE_ACCOUNT: None

KUBERNETES_NODE_SELECTOR: str

KUBERNETES_TOLERATIONS: str

KUBERNETES_PERSISTENT_VOLUME_CLAIMS: str

KUBERNETES_SECRETS: str

KUBERNETES_LABELS: str

KUBERNETES_ANNOTATIONS: str

KUBERNETES_GPU_VENDOR: str

KUBERNETES_CONTAINER_IMAGE: None

KUBERNETES_IMAGE_PULL_POLICY: None

KUBERNETES_IMAGE_PULL_SECRETS: str

KUBERNETES_CONTAINER_REGISTRY: None

KUBERNETES_FETCH_EC2_METADATA: bool

KUBERNETES_SHARED_MEMORY: None

KUBERNETES_PORT: None

KUBERNETES_CPU: None

KUBERNETES_MEMORY: None

KUBERNETES_DISK: None

KUBERNETES_QOS: str

KUBERNETES_CONDA_ARCH: None

ARGO_WORKFLOWS_KUBERNETES_SECRETS: str

ARGO_WORKFLOWS_ENV_VARS_TO_SKIP: str

KUBERNETES_JOBSET_GROUP: str

KUBERNETES_JOBSET_VERSION: str

ARGO_EVENTS_SERVICE_ACCOUNT: None

ARGO_EVENTS_EVENT_BUS: str

ARGO_EVENTS_EVENT_SOURCE: None

ARGO_EVENTS_EVENT: None

ARGO_EVENTS_WEBHOOK_URL: None

ARGO_EVENTS_INTERNAL_WEBHOOK_URL: None

ARGO_EVENTS_WEBHOOK_AUTH: str

ARGO_WORKFLOWS_UI_URL: None

AIRFLOW_KUBERNETES_STARTUP_TIMEOUT_SECONDS: int

AIRFLOW_KUBERNETES_CONN_ID: None

AIRFLOW_KUBERNETES_KUBECONFIG_FILE: None

AIRFLOW_KUBERNETES_KUBECONFIG_CONTEXT: None

CONDA_PACKAGE_S3ROOT: None

CONDA_PACKAGE_AZUREROOT: None

CONDA_PACKAGE_GSROOT: None

CONDA_DEPENDENCY_RESOLVER: str

CONDA_USE_FAST_INIT: bool

ESCAPE_HATCH_WARNING: bool

FEAT_ALWAYS_UPLOAD_CODE_PACKAGE: bool

DEBUG_OPTIONS: list

DEBUG_SUBCOMMAND: bool

DEBUG_SIDECAR: bool

DEBUG_S3CLIENT: bool

DEBUG_TRACING: bool

DEBUG_STUBGEN: bool

DEBUG_USERCONF: bool

DEBUG_CONDA: bool

DEBUG_PACKAGE: bool

AWS_SANDBOX_ENABLED: bool

AWS_SANDBOX_STS_ENDPOINT_URL: None

AWS_SANDBOX_API_KEY: None

AWS_SANDBOX_INTERNAL_SERVICE_URL: None

AWS_SANDBOX_REGION: None

KUBERNETES_SANDBOX_INIT_SCRIPT: None

OTEL_ENDPOINT: None

ZIPKIN_ENDPOINT: None

CONSOLE_TRACE_ENABLED: bool

DISABLE_TRACING: bool

MAX_ATTEMPTS: int

CLICK_API_PROCESS_CONFIG: bool

def get_pinned_conda_libs(python_version, datastore_type):
    ...

